summaryrefslogtreecommitdiff
path: root/makima/frontend/src/lib/api.ts
diff options
context:
space:
mode:
authorsoryu <soryu@soryu.co>2026-01-20 23:20:32 +0000
committerGitHub <noreply@github.com>2026-01-20 23:20:32 +0000
commit7155e6cd7ddf25a5a4d4f6d6abecd49f0cf519dc (patch)
tree2475a951c4bcba685b010909bf4abd5351cb3623 /makima/frontend/src/lib/api.ts
parent055e2c4a72e3b2331a18fdc9f8132ef990af7e38 (diff)
downloadsoryu-7155e6cd7ddf25a5a4d4f6d6abecd49f0cf519dc.tar.gz
soryu-7155e6cd7ddf25a5a4d4f6d6abecd49f0cf519dc.zip
Add non-blocking persistent contract completion questions (#14)
* [WIP] Heartbeat checkpoint - 2026-01-20 22:40:37 UTC * Task completion checkpoint
Diffstat (limited to 'makima/frontend/src/lib/api.ts')
-rw-r--r--makima/frontend/src/lib/api.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/makima/frontend/src/lib/api.ts b/makima/frontend/src/lib/api.ts
index 78e52cd..14ec9f2 100644
--- a/makima/frontend/src/lib/api.ts
+++ b/makima/frontend/src/lib/api.ts
@@ -1948,8 +1948,8 @@ export interface PendingQuestion {
createdAt: string;
/** Whether multiple choices can be selected */
multiSelect?: boolean;
- /** Question type - "general" for regular questions, "phase_confirmation" for phase transitions */
- questionType?: "general" | "phase_confirmation";
+ /** Question type - "general" for regular questions, "phase_confirmation" for phase transitions, "contract_complete" for contract completion */
+ questionType?: "general" | "phase_confirmation" | "contract_complete";
/** Phase confirmation specific data (when questionType is "phase_confirmation") */
phaseConfirmation?: {
currentPhase: ContractPhase;